@@ -2,23 +2,10 @@
   kmime_util.cpp
 
   KMime, the KDE Internet mail/usenet news message library.
-  Copyright (c) 2001 the KMime authors.
+  SPDX-FileCopyrightText: 2001 the KMime authors.
   See file AUTHORS for details
 
-  This library is free software; you can redistribute it and/or
-  modify it under the terms of the GNU Library General Public
-  License as published by the Free Software Foundation; either
-  version 2 of the License, or (at your option) any later version.
-
-  This library is distributed in the hope that it will be useful,
-  but WITHOUT ANY WARRANTY; without even the implied warranty of
-  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
-  Library General Public License for more details.
-
-  You should have received a copy of the GNU Library General Public License
-  along with this library; see the file COPYING.LIB.  If not, write to
-  the Free Software Foundation, Inc., 51 Franklin Street, Fifth Floor,
-  Boston, MA 02110-1301, USA.
+  SPDX-License-Identifier: LGPL-2.0-or-later
 */
 
 #include "kmime_util.h"
@@ -37,8 +24,6 @@
 #include <KCharsets>
 #include <QCoreApplication>
 
-#include <QVector>
-#include <QString>
 #include <QTextCodec>
 
 #include <ctype.h>
@@ -68,7 +53,7 @@ QByteArray cachedCharset(const QByteArray &name)
 
 bool isUsAscii(const QString &s)
 {
-    uint sLength = s.length();
+    const uint sLength = s.length();
     for (uint i = 0; i < sLength; i++) {
         if (s.at(i).toLatin1() <= 0) {     // c==0: non-latin1, c<0: non-us-ascii
             return false;
